@@ -1,5 +1,5 @@
 from kokkos_test_case import KokkosTestCase
-from unittest import TestCase, skipIf
+from unittest import TestCase
 import numpy as np
 import math
 import random
@@ -21,15 +21,6 @@ try:
 except:
     from functools import partialmethod
 
-def skip_additional_initializes_for_kokkos():
-    # don't reinitialize with CUDA
-    # get status
-    st = pycompadre.Kokkos.status()
-    if "KOKKOS_ENABLE_CUDA: yes" in st:
-        return True
-    return False
-kokkos_skip_check = skipIf(skip_additional_initializes_for_kokkos(), "Can't reinitialize Kokkos with CUDA")
-
 # function used to generate sample data
 def exact(coord,order,dimension):
     x = coord[0]
@@ -227,47 +218,6 @@ def remap(polyOrder,dimension,additional_sites=False,epsilon_multiplier=1.5,reco
         return l2_error, h1_seminorm_error, additional_sites_l2_error
     return l2_error, h1_seminorm_error
 
-class TestKokkosParser(TestCase):
-
-    @kokkos_skip_check
-    def test_init_and_finalize_sysargv(self):
-        pycompadre.Kokkos.initialize(sys.argv)
-        pycompadre.Kokkos.finalize()
-
-    @kokkos_skip_check
-    def test_init_and_finalize_empty(self):
-        pycompadre.Kokkos.initialize()
-        pycompadre.Kokkos.finalize()
-
-    @kokkos_skip_check
-    def test_init_and_finalize_list(self):
-        pycompadre.Kokkos.initialize(["--kokkos-num-threads=4"])
-        pycompadre.Kokkos.finalize()
-
-    @kokkos_skip_check
-    def test_init_and_finalize_initarguments(self):
-        kia = pycompadre.Kokkos.InitArguments()
-        pycompadre.Kokkos.initialize(kia)
-        pycompadre.Kokkos.finalize()
-
-    @kokkos_skip_check
-    def test_scope_guard_sysargv(self):
-        pycompadre.KokkosParser(sys.argv)
-
-    @kokkos_skip_check
-    def test_scope_guard_empty(self):
-        pycompadre.KokkosParser()
-
-    @kokkos_skip_check
-    def test_scope_guard_list(self):
-        pycompadre.KokkosParser(["--kokkos-num-threads=4"])
-
-    @kokkos_skip_check
-    def test_scope_guard_initarguments(self):
-        kia = pycompadre.Kokkos.InitArguments()
-        pycompadre.KokkosParser(kia)
-
-
 class TestPyCOMPADRE(KokkosTestCase):
 
     # most tests are added from a dictionary below 
